========
Usage
========

To use My Checker in a project::

	>>> import my_checker
	>>> if my_checker.check_math(6 * 9 - 12, 42):
	...     print("The answer!")
	... else:
	...     print("Sorry for the inconvenience.")
	The answer!